@@ -313,6 +313,13 @@ Variables substituted::
         help="Specifies the OS of the base AMI. "
         "Valid options are: alinux, ubuntu1404, ubuntu1604, centos6, centos7.",
     )
+    pami.add_argument(
+        "-i",
+        "--instance-type",
+        dest="instance_type",
+        default="t2.xlarge",
+        help="Sets instance type to build the ami on. Defaults to t2.xlarge.",
+    )
     pami.add_argument(
         "-ap",
         "--ami-name-prefix",
