@@ -81,10 +81,6 @@ def create(args):  # noqa: C901 FIXME!!!
         aws_secret_access_key=config.aws_secret_access_key,
     )
 
-    # Set the ComputeWaitConditionCount parameter to match DesiredSize
-    if "DesiredSize" in config.parameters:
-        config.parameters["ComputeWaitConditionCount"] = config.parameters["DesiredSize"]
-
     # Get the MasterSubnetId and use it to determine AvailabilityZone
     if "MasterSubnetId" in config.parameters:
         master_subnet_id = config.parameters["MasterSubnetId"]
@@ -717,11 +713,7 @@ def command(args, extra_args):  # noqa: C901 FIXME!!!
         elif status in valid_status:
             outputs = stack_result.get("Outputs")
             username = _get_output_value(outputs, "ClusterUser")
-            ip = (
-                _get_output_value(outputs, "MasterPublicIP")
-                if _get_output_value(outputs, "MasterPublicIP")
-                else _get_output_value(outputs, "MasterPrivateIP")
-            )
+            ip = _get_output_value(outputs, "MasterPublicIP") or _get_master_server_ip(stack, config)
 
             if not username:
                 LOGGER.info("Failed to get cluster %s username.", args.cluster_name)
@@ -1033,7 +1025,7 @@ def create_ami(args):
     LOGGER.debug("Building AMI based on args %s", str(args))
     results = {}
 
-    instance_type = "t2.large"
+    instance_type = args.instance_type
     try:
         config = cfnconfig.ParallelClusterConfig(args)
 
